Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(654)

Unified Diff: runtime/vm/intrinsifier_ia32.cc

Issue 616983003: Disable 2 intrinsics causing optimizer issues (under investigation). (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intrinsifier_arm64.cc ('k') | runtime/vm/intrinsifier_mips.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intrinsifier_ia32.cc
===================================================================
--- runtime/vm/intrinsifier_ia32.cc (revision 40824)
+++ runtime/vm/intrinsifier_ia32.cc (working copy)
@@ -914,10 +914,11 @@
// TODO(regis): Once this intrinsic is implemented on all architectures, the
// corresponding Dart method will be untested. Add a test with --no-intrinsify.
-void Intrinsifier::Bigint_add(Assembler* assembler) {
- // static void _add(Uint32List digits, int used,
- // Uint32List a_digits, int a_used,
- // Uint32List r_digits)
+void Intrinsifier::Bigint_absAdd(Assembler* assembler) {
+#if 0 // TODO(regis): Re-enable when the optimizer issue is fixed.
+ // static void _absAdd(Uint32List digits, int used,
+ // Uint32List a_digits, int a_used,
+ // Uint32List r_digits)
// Preserve CTX to free ESI.
__ pushl(CTX);
@@ -969,15 +970,17 @@
__ popl(CTX);
// TODO(regis): Confirm that returning Object::null() is not required.
__ ret();
+#endif
}
// TODO(regis): Once this intrinsic is implemented on all architectures, the
// corresponding Dart method will be untested. Add a test with --no-intrinsify.
-void Intrinsifier::Bigint_sub(Assembler* assembler) {
- // static void _sub(Uint32List digits, int used,
- // Uint32List a_digits, int a_used,
- // Uint32List r_digits)
+void Intrinsifier::Bigint_absSub(Assembler* assembler) {
+#if 0 // TODO(regis): Re-enable when the optimizer issue is fixed.
+ // static void _absSub(Uint32List digits, int used,
+ // Uint32List a_digits, int a_used,
+ // Uint32List r_digits)
// Preserve CTX to free ESI.
__ pushl(CTX);
@@ -1025,6 +1028,7 @@
__ popl(CTX);
// TODO(regis): Confirm that returning Object::null() is not required.
__ ret();
+#endif
}
« no previous file with comments | « runtime/vm/intrinsifier_arm64.cc ('k') | runtime/vm/intrinsifier_mips.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698